@@ -3,11 +3,12 @@ use warnings;
 
 package Dist::Zilla::Plugin::ReadmeAnyFromPod;
 # ABSTRACT: Automatically convert POD to a README in any format for Dist::Zilla
-$Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.160630';
+$Dist::Zilla::Plugin::ReadmeAnyFromPod::VERSION = '0.161150';
 use List::Util 1.33 qw( none first );
 use Moose::Util::TypeConstraints qw(enum);
 use Moose;
 use MooseX::Has::Sugar;
+use Path::Tiny 0.004;
 use Scalar::Util 'blessed';
 
 with 'Dist::Zilla::Role::AfterBuild',
@@ -225,9 +226,7 @@ sub _create_readme {
 
         my $content = $self->get_readme_content();
 
-        require Path::Tiny;
-        Path::Tiny->VERSION(0.004);
-        my $destination_file = Path::Tiny::path($self->zilla->root, $filename);
+        my $destination_file = path($self->zilla->root)->child($filename);
         if (-e $destination_file) {
             $self->log("overriding $filename in root");
         }
@@ -336,7 +335,7 @@ Dist::Zilla::Plugin::ReadmeAnyFromPod - Automatically convert POD to a README in
 
 =head1 VERSION
 
-version 0.160630
+version 0.161150
 
 =head1 SYNOPSIS
 
